==> apigateway-1.137.0-sources.jar: software/amazon/awscdk/services/apigateway/MethodProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.apigateway.*;
 * Authorizer authorizer;
 * Integration integration;
 * Model model;
 * RequestValidator requestValidator;
 * Resource resource;
 * MethodProps methodProps = MethodProps.builder()
 *         .httpMethod("httpMethod")
 *         .resource(resource)
 *         // the properties below are optional
 *         .integration(integration)
 *         .options(MethodOptions.builder()
 *                 .apiKeyRequired(false)
 *                 .authorizationScopes(List.of("authorizationScopes"))
 *                 .authorizationType(AuthorizationType.NONE)
 *                 .authorizer(authorizer)
 *                 .methodResponses(List.of(MethodResponse.builder()
 *                         .statusCode("statusCode")
 *                         // the properties below are optional
 *                         .responseModels(Map.of(
 *                                 "responseModelsKey", model))
 *                         .responseParameters(Map.of(
 *                                 "responseParametersKey", false))
 *                         .build()))
 *                 .operationName("operationName")
 *                 .requestModels(Map.of(
 *                         "requestModelsKey", model))
 *                 .requestParameters(Map.of(
 *                         "requestParametersKey", false))
 *                 .requestValidator(requestValidator)
 *                 .requestValidatorOptions(RequestValidatorOptions.builder()
 *                         .requestValidatorName("requestValidatorName")
 *                         .validateRequestBody(false)
 *                         .validateRequestParameters(false)
 *                         .build())
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-21T16:39:03.337Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.MethodProps")
@software.amazon.jsii.Jsii.Proxy(MethodProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MethodProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The HTTP method ("GET", "POST", "PUT", ...) that clients use to call this method.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getHttpMethod();

    /**
     * The backend system that the method calls when it receives a request.
     * <p>
     * Default: - a new `MockIntegration`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.apigateway.Integration getIntegration() {
        return null;
    }

    /**
     * Method options.
     * <p>
     * Default: - No options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.apigateway.MethodOptions getOptions() {
        return null;
    }

    /**
     * The resource this method is associated with.
     * <p>
     * For root resource methods,
     * specify the <code>RestApi</code> object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.IResource getResource();

    /**
     * @return a {@link Builder} of {@link MethodProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MethodProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MethodProps> {
        java.lang.String httpMethod;
        software.amazon.awscdk.services.apigateway.Integration integration;
        software.amazon.awscdk.services.apigateway.MethodOptions options;
        software.amazon.awscdk.services.apigateway.IResource resource;

        /**
         * Sets the value of {@link MethodProps#getHttpMethod}
         * @param httpMethod The HTTP method ("GET", "POST", "PUT", ...) that clients use to call this method. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpMethod(java.lang.String httpMethod) {
            this.httpMethod = httpMethod;
            return this;
        }

        /**
         * Sets the value of {@link MethodProps#getIntegration}
         * @param integration The backend system that the method calls when it receives a request.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder integration(software.amazon.awscdk.services.apigateway.Integration integration) {
            this.integration = integration;
            return this;
        }

        /**
         * Sets the value of {@link MethodProps#getOptions}
         * @param options Method options.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder options(software.amazon.awscdk.services.apigateway.MethodOptions options) {
            this.options = options;
            return this;
        }

        /**
         * Sets the value of {@link MethodProps#getResource}
         * @param resource The resource this method is associated with. This parameter is required.
         *                 For root resource methods,
         *                 specify the <code>RestApi</code> object.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resource(software.amazon.awscdk.services.apigateway.IResource resource) {
            this.resource = resource;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MethodProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MethodProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MethodProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MethodProps {
        private final java.lang.String httpMethod;
        private final software.amazon.awscdk.services.apigateway.Integration integration;
        private final software.amazon.awscdk.services.apigateway.MethodOptions options;
        private final software.amazon.awscdk.services.apigateway.IResource resource;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.httpMethod = software.amazon.jsii.Kernel.get(this, "httpMethod", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.integration = software.amazon.jsii.Kernel.get(this, "integration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.Integration.class));
            this.options = software.amazon.jsii.Kernel.get(this, "options", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.MethodOptions.class));
            this.resource = software.amazon.jsii.Kernel.get(this, "resource", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.IResource.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.httpMethod = java.util.Objects.requireNonNull(builder.httpMethod, "httpMethod is required");
            this.integration = builder.integration;
            this.options = builder.options;
            this.resource = java.util.Objects.requireNonNull(builder.resource, "resource is required");
        }

        @Override
        public final java.lang.String getHttpMethod() {
            return this.httpMethod;
        }

        @Override
        public final software.amazon.awscdk.services.apigateway.Integration getIntegration() {
            return this.integration;
        }

        @Override
        public final software.amazon.awscdk.services.apigateway.MethodOptions getOptions() {
            return this.options;
        }

        @Override
        public final software.amazon.awscdk.services.apigateway.IResource getResource() {
            return this.resource;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("httpMethod", om.valueToTree(this.getHttpMethod()));
            if (this.getIntegration() != null) {
                data.set("integration", om.valueToTree(this.getIntegration()));
            }
            if (this.getOptions() != null) {
                data.set("options", om.valueToTree(this.getOptions()));
            }
            data.set("resource", om.valueToTree(this.getResource()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.MethodProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MethodProps.Jsii$Proxy that = (MethodProps.Jsii$Proxy) o;

            if (!httpMethod.equals(that.httpMethod)) return false;
            if (this.integration != null ? !this.integration.equals(that.integration) : that.integration != null) return false;
            if (this.options != null ? !this.options.equals(that.options) : that.options != null) return false;
            return this.resource.equals(that.resource);
        }

        @Override
        public final int hashCode() {
            int result = this.httpMethod.hashCode();
            result = 31 * result + (this.integration != null ? this.integration.hashCode() : 0);
            result = 31 * result + (this.options != null ? this.options.hashCode() : 0);
            result = 31 * result + (this.resource.hashCode());
            return result;
        }
    }
}

==> apigateway-1.138.0-sources.jar: software/amazon/awscdk/services/apigateway/MethodProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.apigateway.*;
 * Authorizer authorizer;
 * Integration integration;
 * Model model;
 * RequestValidator requestValidator;
 * Resource resource;
 * MethodProps methodProps = MethodProps.builder()
 *         .httpMethod("httpMethod")
 *         .resource(resource)
 *         // the properties below are optional
 *         .integration(integration)
 *         .options(MethodOptions.builder()
 *                 .apiKeyRequired(false)
 *                 .authorizationScopes(List.of("authorizationScopes"))
 *                 .authorizationType(AuthorizationType.NONE)
 *                 .authorizer(authorizer)
 *                 .methodResponses(List.of(MethodResponse.builder()
 *                         .statusCode("statusCode")
 *                         // the properties below are optional
 *                         .responseModels(Map.of(
 *                                 "responseModelsKey", model))
 *                         .responseParameters(Map.of(
 *                                 "responseParametersKey", false))
 *                         .build()))
 *                 .operationName("operationName")
 *                 .requestModels(Map.of(
 *                         "requestModelsKey", model))
 *                 .requestParameters(Map.of(
 *                         "requestParametersKey", false))
 *                 .requestValidator(requestValidator)
 *                 .requestValidatorOptions(RequestValidatorOptions.builder()
 *                         .requestValidatorName("requestValidatorName")
 *                         .validateRequestBody(false)
 *                         .validateRequestParameters(false)
 *                         .build())
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.50.0 (build d1830a4)", date = "2022-01-04T15:38:57.295Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.MethodProps")
@software.amazon.jsii.Jsii.Proxy(MethodProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MethodProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The HTTP method ("GET", "POST", "PUT", ...) that clients use to call this method.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getHttpMethod();

    /**
     * The resource this method is associated with.
     * <p>
     * For root resource methods,
     * specify the <code>RestApi</code> object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.IResource getResource();

    /**
     * The backend system that the method calls when it receives a request.
     * <p>
     * Default: - a new `MockIntegration`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.apigateway.Integration getIntegration() {
        return null;
    }

    /**
     * Method options.
     * <p>
     * Default: - No options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.apigateway.MethodOptions getOptions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MethodProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MethodProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MethodProps> {
        java.lang.String httpMethod;
        software.amazon.awscdk.services.apigateway.IResource resource;
        software.amazon.awscdk.services.apigateway.Integration integration;
        software.amazon.awscdk.services.apigateway.MethodOptions options;

        /**
         * Sets the value of {@link MethodProps#getHttpMethod}
         * @param httpMethod The HTTP method ("GET", "POST", "PUT", ...) that clients use to call this method. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpMethod(java.lang.String httpMethod) {
            this.httpMethod = httpMethod;
            return this;
        }

        /**
         * Sets the value of {@link MethodProps#getResource}
         * @param resource The resource this method is associated with. This parameter is required.
         *                 For root resource methods,
         *                 specify the <code>RestApi</code> object.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resource(software.amazon.awscdk.services.apigateway.IResource resource) {
            this.resource = resource;
            return this;
        }

        /**
         * Sets the value of {@link MethodProps#getIntegration}
         * @param integration The backend system that the method calls when it receives a request.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder integration(software.amazon.awscdk.services.apigateway.Integration integration) {
            this.integration = integration;
            return this;
        }

        /**
         * Sets the value of {@link MethodProps#getOptions}
         * @param options Method options.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder options(software.amazon.awscdk.services.apigateway.MethodOptions options) {
            this.options = options;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MethodProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MethodProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MethodProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MethodProps {
        private final java.lang.String httpMethod;
        private final software.amazon.awscdk.services.apigateway.IResource resource;
        private final software.amazon.awscdk.services.apigateway.Integration integration;
        private final software.amazon.awscdk.services.apigateway.MethodOptions options;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.httpMethod = software.amazon.jsii.Kernel.get(this, "httpMethod", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.resource = software.amazon.jsii.Kernel.get(this, "resource", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.IResource.class));
            this.integration = software.amazon.jsii.Kernel.get(this, "integration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.Integration.class));
            this.options = software.amazon.jsii.Kernel.get(this, "options", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.MethodOptions.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.httpMethod = java.util.Objects.requireNonNull(builder.httpMethod, "httpMethod is required");
            this.resource = java.util.Objects.requireNonNull(builder.resource, "resource is required");
            this.integration = builder.integration;
            this.options = builder.options;
        }

        @Override
        public final java.lang.String getHttpMethod() {
            return this.httpMethod;
        }

        @Override
        public final software.amazon.awscdk.services.apigateway.IResource getResource() {
            return this.resource;
        }

        @Override
        public final software.amazon.awscdk.services.apigateway.Integration getIntegration() {
            return this.integration;
        }

        @Override
        public final software.amazon.awscdk.services.apigateway.MethodOptions getOptions() {
            return this.options;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("httpMethod", om.valueToTree(this.getHttpMethod()));
            data.set("resource", om.valueToTree(this.getResource()));
            if (this.getIntegration() != null) {
                data.set("integration", om.valueToTree(this.getIntegration()));
            }
            if (this.getOptions() != null) {
                data.set("options", om.valueToTree(this.getOptions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.MethodProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MethodProps.Jsii$Proxy that = (MethodProps.Jsii$Proxy) o;

            if (!httpMethod.equals(that.httpMethod)) return false;
            if (!resource.equals(that.resource)) return false;
            if (this.integration != null ? !this.integration.equals(that.integration) : that.integration != null) return false;
            return this.options != null ? this.options.equals(that.options) : that.options == null;
        }

        @Override
        public final int hashCode() {
            int result = this.httpMethod.hashCode();
            result = 31 * result + (this.resource.hashCode());
            result = 31 * result + (this.integration != null ? this.integration.hashCode() : 0);
            result = 31 * result + (this.options != null ? this.options.hashCode() : 0);
            return result;
        }
    }
}
